-
- Enclosing class:
- JNDI
public static interface JNDI.LimitedContextA lookalike method forContextthat allows sandboxing resolution.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description java.lang.Objectlookup(java.lang.String resource)Looks up a resource in the context, but only allows resources that are in the allowed set.
-
-
-
Method Detail
-
lookup
java.lang.Object lookup(java.lang.String resource) throws javax.naming.NamingExceptionLooks up a resource in the context, but only allows resources that are in the allowed set.- Parameters:
resource- the resource to look up- Returns:
- the object bound to the resource
- Throws:
javax.naming.NamingException- if the resource is not allowed or if the lookup fails as perContext.lookup(String)
-
-