Class Newlines


  • public final class Newlines
    extends Object
    This type exposes helper methods that will help defend against newline-based attacks.
    • Method Detail

      • stripAll

        public static String stripAll​(String value)
        Removes newlines from the given string, if any exist.
        Parameters:
        value - the given string to sanitize
        Returns:
        a String identical to the one given, without newline characters