Enum UrlProtocol

    • Enum Constant Detail

      • ANY

        public static final UrlProtocol ANY
        A protocol indicating that _any_ protocol is allowed.
      • RESOURCE

        public static final UrlProtocol RESOURCE
        Resource
      • GOPHER

        public static final UrlProtocol GOPHER
        Gopher
      • NEWS

        public static final UrlProtocol NEWS
        News

        https://www.ietf.org/archive/id/draft-ellermann-news-nntp-uri-11.html

      • MAILTO

        public static final UrlProtocol MAILTO
        mailto
      • TELNET

        public static final UrlProtocol TELNET
        telnet
      • CLASSPATH

        public static final UrlProtocol CLASSPATH
        Classpath
    • Method Detail

      • values

        public static UrlProtocol[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (UrlProtocol c : UrlProtocol.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static UrlProtocol valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null