Package io.github.pixee.security
Class XMLInputFactorySecurity
- java.lang.Object
-
- io.github.pixee.security.XMLInputFactorySecurity
-
public final class XMLInputFactorySecurity extends Object
This type exposes helper methods that will help defend against XXE attacks inXMLInputFactory.For more on XXE:
-
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static XMLInputFactoryhardenFactory(XMLInputFactory factory)Harden theXMLInputFactoryagainst external entity attacksstatic XMLInputFactoryhardenFactory(XMLInputFactory factory, Set<XMLRestrictions> restrictions)Harden theXMLInputFactoryagainst XML-based attacks with the given restrictions.
-
-
-
Method Detail
-
hardenFactory
public static XMLInputFactory hardenFactory(XMLInputFactory factory)
Harden theXMLInputFactoryagainst external entity attacks
-
hardenFactory
public static XMLInputFactory hardenFactory(XMLInputFactory factory, Set<XMLRestrictions> restrictions)
Harden theXMLInputFactoryagainst XML-based attacks with the given restrictions.
-
-