Uses of Class
io.github.pixee.security.ReflectionRestrictions
-
Packages that use ReflectionRestrictions Package Description io.github.pixee.security The intent of these types is to offer APIs that are usable by developers for implementing common security tasks. -
-
Uses of ReflectionRestrictions in io.github.pixee.security
Methods in io.github.pixee.security that return ReflectionRestrictions Modifier and Type Method Description static ReflectionRestrictionsReflectionRestrictions. valueOf(String name)Returns the enum constant of this type with the specified name.static ReflectionRestrictions[]ReflectionRestrictions. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in io.github.pixee.security that return types with arguments of type ReflectionRestrictions Modifier and Type Method Description static Set<ReflectionRestrictions>Reflection. defaultRestrictions()Provide the default restrictions for loading a type that will work for the vast majority of applications.Method parameters in io.github.pixee.security with type arguments of type ReflectionRestrictions Modifier and Type Method Description static Class<?>Reflection. loadAndVerify(String name, Set<ReflectionRestrictions> restrictions)This method sandboxes the classloading to prevent possibly dangerous types from being loaded.
-