Uses of Class
io.github.pixee.security.SystemCommandRestrictions
-
Packages that use SystemCommandRestrictions Package Description io.github.pixee.security The intent of these types is to offer APIs that are usable by developers for implementing common security tasks. -
-
Uses of SystemCommandRestrictions in io.github.pixee.security
Methods in io.github.pixee.security that return SystemCommandRestrictions Modifier and Type Method Description static SystemCommandRestrictionsSystemCommandRestrictions. valueOf(String name)Returns the enum constant of this type with the specified name.static SystemCommandRestrictions[]SystemCommandRestrictions. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in io.github.pixee.security that return types with arguments of type SystemCommandRestrictions Modifier and Type Method Description static Set<SystemCommandRestrictions>SystemCommand. defaultRestrictions()The default restrictions if none are specified.Method parameters in io.github.pixee.security with type arguments of type SystemCommandRestrictions Modifier and Type Method Description static ProcessSystemCommand. runCommand(Runtime runtime, String[] command, String[] envp, File dir, Set<SystemCommandRestrictions> restrictions)Same asSystemCommand.runCommand(Runtime, String[], Set)but also include more data to pass intoRuntime.exec(String[], String[], File).static ProcessSystemCommand. runCommand(Runtime runtime, String[] command, String[] envp, Set<SystemCommandRestrictions> restrictions)Same asSystemCommand.runCommand(Runtime, String[], Set)but also include more data to pass intoRuntime.exec(String[], String[]).static ProcessSystemCommand. runCommand(Runtime runtime, String[] command, Set<SystemCommandRestrictions> restrictions)Does the same asRuntime.exec(String[]), but adds restrictions on what types of commands will be allowed.static ProcessSystemCommand. runCommand(Runtime runtime, String command, String[] envp, File dir, Set<SystemCommandRestrictions> restrictions)Same asSystemCommand.runCommand(Runtime, String, Set)but also include more data to pass intoRuntime.exec(String, String[], File).static ProcessSystemCommand. runCommand(Runtime runtime, String command, String[] envp, Set<SystemCommandRestrictions> restrictions)Same asSystemCommand.runCommand(Runtime, String, Set)but also include more data to pass intoRuntime.exec(String, String[]).static ProcessSystemCommand. runCommand(Runtime runtime, String command, Set<SystemCommandRestrictions> restrictions)Does the same asRuntime.exec(String), but adds restrictions on what types of commands will be allowed.
-