Uses of Class
io.github.pixee.security.UrlProtocol
-
Packages that use UrlProtocol Package Description io.github.pixee.security The intent of these types is to offer APIs that are usable by developers for implementing common security tasks. -
-
Uses of UrlProtocol in io.github.pixee.security
Fields in io.github.pixee.security with type parameters of type UrlProtocol Modifier and Type Field Description static Set<UrlProtocol>Urls. HTTP_PROTOCOLSThis is a convenienceSetprovided for most people who probably only want to allow HTTP-based protocols.Methods in io.github.pixee.security that return UrlProtocol Modifier and Type Method Description static UrlProtocolUrlProtocol. valueOf(String name)Returns the enum constant of this type with the specified name.static UrlProtocol[]UrlProtocol. values()Returns an array containing the constants of this enum type, in the order they are declared.Method parameters in io.github.pixee.security with type arguments of type UrlProtocol Modifier and Type Method Description static URLUrls. create(String protocol, String host, int port, String file, URLStreamHandler handler, Set<UrlProtocol> allowedProtocols, HostValidator hostValidator)Convenience method which delegates toUrls.create(URL, Set, HostValidator).static URLUrls. create(String protocol, String host, int port, String file, Set<UrlProtocol> allowedProtocols, HostValidator hostValidator)Convenience method which delegates toUrls.create(URL, Set, HostValidator).static URLUrls. create(String protocol, String host, String file, Set<UrlProtocol> allowedProtocols, HostValidator hostValidator)Convenience method which delegates toUrls.create(URL, Set, HostValidator).static URLUrls. create(String url, Set<UrlProtocol> allowedProtocols, HostValidator validator)static URLUrls. create(URL context, String spec, URLStreamHandler handler, Set<UrlProtocol> allowedProtocols, HostValidator hostValidator)Convenience method which delegates toUrls.create(URL, Set, HostValidator).static URLUrls. create(URL context, String spec, Set<UrlProtocol> allowedProtocols, HostValidator hostValidator)Convenience method which delegates toUrls.create(URL, Set, HostValidator).
-