Uses of Class
io.github.pixee.security.XMLRestrictions
-
Packages that use XMLRestrictions Package Description io.github.pixee.security The intent of these types is to offer APIs that are usable by developers for implementing common security tasks. -
-
Uses of XMLRestrictions in io.github.pixee.security
Methods in io.github.pixee.security that return XMLRestrictions Modifier and Type Method Description static XMLRestrictionsXMLRestrictions. valueOf(String name)Returns the enum constant of this type with the specified name.static XMLRestrictions[]XMLRestrictions. values()Returns an array containing the constants of this enum type, in the order they are declared.Method parameters in io.github.pixee.security with type arguments of type XMLRestrictions Modifier and Type Method Description static XMLInputFactoryXMLInputFactorySecurity. hardenFactory(XMLInputFactory factory, Set<XMLRestrictions> restrictions)Harden theXMLInputFactoryagainst XML-based attacks with the given restrictions.
-