Uses of Package
io.github.pixee.security
-
Packages that use io.github.pixee.security Package Description io.github.pixee.security The intent of these types is to offer APIs that are usable by developers for implementing common security tasks. -
Classes in io.github.pixee.security used by io.github.pixee.security Class Description HostValidator A type that validates hosts to be connected.ReflectionRestrictions The set of restrictions developers can use when usingReflectionAPIs.SystemCommandRestrictions The restrictions that could be applied to a command being run through this type.UrlProtocol The set of protocols that we can allow (notice "ANY") is an option inUrlsmethods.XMLRestrictions The set of restrictions that we can apply to a secured XML read.