Package io.github.pixee.security
Class Newlines
- java.lang.Object
-
- io.github.pixee.security.Newlines
-
public final class Newlines extends Object
This type exposes helper methods that will help defend against newline-based attacks.
-
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static StringstripAll(String value)Removes newlines from the given string, if any exist.
-